==> jc-1.4.0.tar.gz: gnu/xml/xpath/XPathParser__24YyLhsClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyLhsClass

// class file dependencies
// @dep_class 154bcfd56d9d0bb4 gnu_xml_xpath_XPathParser__24YyLhsClass
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyLhsClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyLhsClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$object	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$fields_struct {
	_jc_short_array	*yyLhs;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$object *);

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vmethods	gnu_xml_xpath_XPathParser__24YyLhsClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_refs	gnu_xml_xpath_XPathParser__24YyLhsClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyLhsClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyLhsClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyLhsClass_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/XPathParser__24YyLhsClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyLhsClass

// class file dependencies
// @dep_class 154bcfd56d9d0bb4 gnu_xml_xpath_XPathParser__24YyLhsClass
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyLhsClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyLhsClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$object	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$fields_struct {
	_jc_short_array	*yyLhs;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vmethods	gnu_xml_xpath_XPathParser__24YyLhsClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_refs	gnu_xml_xpath_XPathParser__24YyLhsClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyLhsClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyLhsClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyLhsClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyLhsClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyLhsClass_H_ */
